@@ -13,7 +13,7 @@ use Cv::Seq::Point2;
 use Cv::Seq::Rect;
 use Cv::Seq::SURFPoint;
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 package Cv;
 
@@ -32,6 +32,7 @@ package Cv::More;
 sub import {
 	my $self = shift;
 	for (@_) {
+		next if /^:/;			# ignore
 		if (defined $Cv::O{$_}) {
 			$O{$_} = 1;
 		} else {
@@ -43,6 +44,7 @@ sub import {
 sub unimport {
 	my $self = shift;
 	for (@_) {
+		next if /^:/;			# ignore
 		if (defined $Cv::O{$_}) {
 			$O{$_} = 0;
 		} else {
@@ -474,7 +476,7 @@ C<Cv>. C<Cv::More> is what separated the part of the C<Cv>. So, it is
 enabled by default. Please make a explicit if you do not use.
 
  use Cv;              # enabled Cv::More
- use Cv qw(:nomore);  # disabled Cv::More
+ use Cv -nomore;	  # disabled Cv::More
 
 =head2 Added or Extended Method
 
@@ -778,9 +780,9 @@ L<Cv>
 
 =head1 LICENCE
 
-Yuta MASUDA E<lt>yuta.masuda@newdaysys.co.jpE<gt>
+MASUDA Yuta E<lt>yuta.cpan@gmail.comE<gt>
 
-Copyright (c) 2012 by Yuta MASUDA.
+Copyright (c) 2012, 2013 by MASUDA Yuta.
 
 All rights reserved. This program is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
